==> haskell-authenticate-1.3.5.2-241-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-BSUwT19C9buITJOqKjyOl8
key:                  authenticate-1.3.5.2-BSUwT19C9buITJOqKjyOl8
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  84605493646592e5cef43138a9921b0e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-BSUwT19C9buITJOqKjyOl8
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE
    attoparsec-aeson-2.1.0.0-BEiLkT0rdCWAen0nBrmaBS base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    html-conduit-1.3.2.2-7OteWGabFNf1YJd3eMqlmA
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    xml-conduit-1.9.1.4-AWUHrHEyod1C1UJeqVfDQt

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-243-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-5PrJiLGaSePavhNGp1jFY
key:                  authenticate-1.3.5.2-5PrJiLGaSePavhNGp1jFY
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  4ad3cb944091f048a61a825e7e545838
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-5PrJiLGaSePavhNGp1jFY
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL
    attoparsec-aeson-2.2.0.0-1Dj4q6tPpHs6SGokkiN3Ch base-4.18.2.1
    blaze-builder-0.4.4.1-Hto81bisFYkHXSmpZG8kx7 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy containers-0.6.7
    html-conduit-1.3.2.2-C2pIyvMhdI89YxzeT9ZQDA
    http-conduit-2.3.9.1-4XCjseDTPMR1cOfyxjAQAe
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    xml-conduit-1.9.1.4-6YUKnRkiQ5NBAoTmcKCArn

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
